LSLBacklog class final

How far the listener of a sample or chunk stream is behind the isolate that pulls for it. See onBacklog of LSLInlet.sampleStream.

Constructors

LSLBacklog({required int queued, required int peak, bool cleared = false})
const

Properties

cleared → bool
Whether this is the report that the queue is back under half the threshold. Nothing more is reported until it goes over again.
final
hashCode → int
The hash code for this object.
no setterinherited
peak → int
The most queued has been since it went over the threshold.
final
queued → int
Samples that have been pulled from the inlet and not yet reached the stream: what is queued between the two isolates.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited