queued property
Samples that have been pulled from the inlet and not yet reached the stream: what is queued between the two isolates.
Implementation
final int queued;
Samples that have been pulled from the inlet and not yet reached the stream: what is queued between the two isolates.
final int queued;