LSLMapper class

LSLMapper type mapping.

Handles a lot of the complexity of converting between the LSL / FFI NativeType types and dart Type types. @note This class is a singleton, so it should be used as a static class.

Constructors

LSLMapper()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
pullSampleMap Map<LSLChannelFormat, LSLPullSample<NativeType, dynamic>>
no setter
pushSampleMap Map<LSLChannelFormat, LSLPushSample<NativeType>>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
streamPull(LSLStreamInfo streamInfo) LSLPullSample<NativeType, dynamic>
Gets the LSLPullSample for the given LSLStreamInfo.
streamPush(LSLStreamInfo streamInfo) LSLPushSample<NativeType>
Gets the LSLPushSample for the given LSLStreamInfo.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited