LSLReusableBuffer<T extends NativeType> class abstract

A Reusable buffer for LSL samples to avoid memory allocation overhead.

Implementers

Constructors

LSLReusableBuffer(int capacity, Pointer<T> buffer)
Creates a reusable buffer of the given capacity. @param capacity The capacity of the buffer in number of elements. @param buffer The buffer to store the sample.

Properties

buffer Pointer<T>
The buffer to store the sample.
final
capacity int
Holds the size of the buffer in number of elements, this often corresponds to the number of channels in the sample. But for chunked data, this is the number of chunks times the number of channels.
final
ec Pointer<Int32>
The error code pointer.
final
freed bool
Whether the buffer has been freed. This is used to prevent double freeing of the buffer.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

free() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited