receivedClock property

double receivedClock
final

lsl_local_clock() as the pull that returned the first sample came back: when the chunk began to be available to this process. The first readyCount samples were in the inlet by then; the rest arrived within the coalesce time after it. As LSLTimedSample.receivedClock, it is an arrival only if the isolate was waiting for the first sample.

Implementation

final double receivedClock;