childValueNamed method
Text content of the first child element named name (empty if there
is no such child or it has no text).
Implementation
String childValueNamed(String name) {
final valuePtr = _withUtf8(name, (n) => lsl_child_value_n(xmlPtr, n));
if (valuePtr.isNullPointer) {
return '';
}
return valuePtr.cast<Utf8>().toDartString();
}