lsl_set_config_filename function

  1. @Native<NativeLsl_destroy_string>()
void lsl_set_config_filename(
  1. Pointer<Char> filename
)

Set the path of the configuration file to be used by liblsl.

This must be called before any other LSL function; otherwise the setting has no effect, as the configuration is loaded lazily on first use. See also the precedence list in api_config.h.

Implementation

@ffi.Native<NativeLsl_set_config_filename>()
external void lsl_set_config_filename(ffi.Pointer<ffi.Char> filename);