LSLPullSample<T extends NativeType, D> class
abstract
The base class for all LSL pull sample types.
- Annotations
-
- @Todo.new('zeyus', 'Seperate the pointer alloc / native call from sample creation.')
Constructors
-
LSLPullSample(DartLSLPullSample<
T> _pullFn) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allocBuffer(
int channels) → Pointer< T> -
bufferToList(
Pointer< T> buffer, int channels) → IList<D> -
call(
lsl_inlet inlet, int channels, double timeout) → LSLSample< D> -
createReusableBuffer(
int channels) → LSLReusableBuffer< T> -
createSample(
Pointer< T> buffer, lsl_inlet inlet, int channels, double timeout) → LSLSample<D> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pullSample(
Pointer< T> buffer, lsl_inlet inlet, int channels, double timeout) → LSLSamplePointer<T> -
Allocates a sample buffer and calls the LSL pull function.
@param
bufferThe buffer to store the sample. @paraminletThe inlet to pull the sample from. @paramchannelsThe number of channels in the sample. @paramtimeoutThe timeout in seconds. @return LSLSamplePointer The sample pointer. -
pullSampleInto(
Pointer< T> buffer, lsl_inlet inlet, int channels, double timeout, Pointer<Int32> ec) → Future<LSLSamplePointer< T> > -
Pulls a sample into the provided reusable buffer.
@param
bufferThe buffer / LSLReusableBuffer.buffer to store the sample. @paraminletThe inlet to pull the sample from. @paramchannelsThe number of channels in the sample. @paramtimeoutThe timeout in seconds. @return LSLSample The sample. @note This function is asynchronous and returns a Future. @note Thebuffermust be allocated with the same number of channels as the sample. @note Thebuffermust be freed after use. -
pullSampleIntoSync(
Pointer< T> buffer, lsl_inlet inlet, int channels, double timeout, Pointer<Int32> ec) → LSLSamplePointer<T> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited