LSLPushSample<T extends NativeType> class
abstract
The base class for all LSL push sample types.
Constructors
-
LSLPushSample(DartLSLPushSample<
T> _pushFn) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allocBuffer(
int channels) → Pointer< T> - Allocates a buffer of the given type. @note this does NO checking if the buffer allocation was successful.
-
call(
lsl_outlet out, Pointer< T> data) → int -
createReusableBuffer(
int channels) → LSLReusableBuffer< T> - Maybe this isn't needed because the ec is allocated but unused for push.
-
listToBuffer(
IList samples, Pointer< T> buffer) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited