capacity property
Holds the size of the buffer in number of elements, this often corresponds to the number of channels in the sample. But for chunked data, this is the number of chunks times the number of channels.
Implementation
final int capacity;
Holds the size of the buffer in number of elements, this often corresponds to the number of channels in the sample. But for chunked data, this is the number of chunks times the number of channels.
final int capacity;