LSLReusableBufferFloat class
Properties
-
buffer
→ Pointer<Float>
-
The buffer to store the sample.
finalinherited
-
capacity
→ int
-
Holds the size of the buffer in number of elements, this often
corresponds to the number of channels in the sample.
But for chunked data, this is the number of chunks times the number of
channels.
finalinherited
-
ec
→ Pointer<Int32>
-
The error code pointer.
finalinherited
-
freed
→ bool
-
Whether the buffer has been freed.
This is used to prevent double freeing of the buffer.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
free()
→ void
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited