lsl_set_config_content function
Set the configuration content (as an INI string) to be used by liblsl.
This must be called before any other LSL function; otherwise the setting has no effect, as the configuration is loaded lazily on first use. When set, this content takes precedence over any configuration file.
@note The content is discarded after liblsl has initialized.
Implementation
@ffi.Native<NativeLsl_set_config_content>()
external void lsl_set_config_content(ffi.Pointer<ffi.Char> content);