lsl_set_config_filename function
Set the path of the configuration file to be used by liblsl.
This must be called before any other LSL function; otherwise the setting has no effect, as the configuration is loaded lazily on first use. See also the precedence list in api_config.h.
Implementation
@ffi.Native<NativeLsl_set_config_filename>()
external void lsl_set_config_filename(ffi.Pointer<ffi.Char> filename);